==> sangtm-validate-html-css-js-1.0.1.tgz: package/src/index.js <==
'use strict';

/**
 * Load file settings
 */
var fileExists = require('file-exists');

// load file setting default in this plugin.
var settings = require('./settings');

//load file setting custom
if(fileExists.sync('settings.json')){
	settings = require('../../settings');
} else {
	console.log("You have not created settings.json file. We will run as setting default.");
}
var Transform = require('stream').Transform;



/**
 * Gulp Packages
 */

// General
var gulp = require('gulp'),
    fancyLog = require('fancy-log'),
    colors = require('ansi-colors'),
    livereload = require('gulp-livereload'),
    browserSync = require('browser-sync').create(),
    concat = require('gulp-concat'),
    foreach = require('gulp-foreach'),
	minify = require('gulp-minify'),
    sourcemaps = require("gulp-sourcemaps");


// HTML:  use library gulp-w3cjs
var w3cjs = require('gulp-w3cjs'),
    htmllint = require('gulp-htmllint');

// Styles
var less = require('gulp-lesshint'),
    sassLint = require('gulp-sass-lint'),
    stylelint = require('gulp-stylelint'),
    sass = require('gulp-sass'),
    autoprefixer = require('gulp-autoprefixer');

// Script
var jslint = require('gulp-jslint'),
    jshint = require('gulp-jshint'),
    stylish = require('jshint-stylish');

	browserSync.init({
		server: {
			baseDir: settings.paths.html.output
		}
	});

/**
 * Define out task
 */
function compile(path, task) {
	console.log(path.html.input);
	// validate html
    gulp.task('html', function (done) {
        gulp.src(path.html.input)
            .pipe(w3cjs())
            .pipe(w3cjs.reporter())
			.pipe(gulp.dest(path.html.output));;
		done();
    });


	//build, optimize script
    gulp.task('scripts', function (done) {
        return gulp.src(path.scripts.input)
            .pipe(sourcemaps.init())
            .pipe(jshint())
            .pipe(jshint.reporter(stylish)) // Console output
            .pipe(sourcemaps.write())
            .pipe(concat('script.js'))
			.pipe(minify())
            .pipe(gulp.dest(path.scripts.output));
		done();
    });

	//build style
    gulp.task('styles', function (done) {
        // To Do and return task script here
        return gulp.src(path.styles.input)
            .pipe(sourcemaps.init())
            .pipe(stylelint({
                reporters: [
                    {formatter: 'string', console: true}
                ],
                fix: true
            }))
            .pipe(sass({
                outputStyle: 'expanded',
                indentType: 'space',
                indentWidth: 4
            })).on('error', sass.logError)
            .pipe(autoprefixer({
                browsers: ['last 5 versions']
            }))
            .pipe(sourcemaps.write())
            .pipe(concat('style.css'))
			.pipe(minify())
            .pipe(gulp.dest(path.styles.output))
		done();
    });

// Spin up livereload server and listen for file changes
    gulp.task('listen', function (done) {

        gulp.watch(path.styles.input).on('change', gulp.series(['styles', 'refresh']));
        gulp.watch(path.scripts.input).on('change', gulp.series(['scripts', 'refresh']));
    });

// Run livereload after file change
    gulp.task('refresh', function () {
        return browserSync.reload();
    });
    return gulp.parallel(task);
	
}; //End function


//
var taskList = [];
// Add task from settings on/off
for (var key in settings.task){
    if(settings.task[key] === true || settings.task[key] === "true") taskList.push(key);
}

// Add task listen
taskList.push('listen');

// hard code to test each task
// var taskList = ['html'];

exports.runTask = compile(settings.paths, taskList);

gulp.task('default', compile(settings.paths, taskList));


// gulp.task('default', gulp.series(taskList), function () {
//
// });


// gulp.task('default', gulp.parallel(taskList), function () {
//
// });

==> sangtm-validate-html-css-js-1.0.2.tgz: package/src/index.js <==
'use strict';

/**
 * Load file settings
 */
var fileExists = require('file-exists');

// load file setting default in this plugin.
var settings = require('./settings');

//load file setting custom
if(fileExists.sync('settings.json')){
	settings = require('../../../settings');
} else {
	console.log("You have not created settings.json file. We will run as setting default.");
}
var Transform = require('stream').Transform;



/**
 * Gulp Packages
 */

// General
var gulp = require('gulp'),
    fancyLog = require('fancy-log'),
    colors = require('ansi-colors'),
    livereload = require('gulp-livereload'),
    browserSync = require('browser-sync').create(),
    concat = require('gulp-concat'),
    foreach = require('gulp-foreach'),
	minify = require('gulp-minify'),
    sourcemaps = require("gulp-sourcemaps");


// HTML:  use library gulp-w3cjs
var w3cjs = require('gulp-w3cjs'),
    htmllint = require('gulp-htmllint');

// Styles
var less = require('gulp-lesshint'),
    sassLint = require('gulp-sass-lint'),
    stylelint = require('gulp-stylelint'),
    sass = require('gulp-sass'),
    autoprefixer = require('gulp-autoprefixer');

// Script
var jslint = require('gulp-jslint'),
    jshint = require('gulp-jshint'),
    stylish = require('jshint-stylish');

	browserSync.init({
		server: {
			baseDir: settings.paths.html.output
		}
	});

/**
 * Define out task
 */
function compile(path, task) {
	console.log(path.html.input);
	// validate html
    gulp.task('html', function (done) {
        gulp.src(path.html.input)
            .pipe(w3cjs())
            .pipe(w3cjs.reporter())
			.pipe(gulp.dest(path.html.output));;
		done();
    });


	//build, optimize script
    gulp.task('scripts', function (done) {
        return gulp.src(path.scripts.input)
            .pipe(sourcemaps.init())
            .pipe(jshint())
            .pipe(jshint.reporter(stylish)) // Console output
            .pipe(sourcemaps.write())
            .pipe(concat('script.js'))
			.pipe(minify())
            .pipe(gulp.dest(path.scripts.output));
		done();
    });

	//build style
    gulp.task('styles', function (done) {
        // To Do and return task script here
        return gulp.src(path.styles.input)
            .pipe(sourcemaps.init())
            .pipe(stylelint({
                reporters: [
                    {formatter: 'string', console: true}
                ],
                fix: true
            }))
            .pipe(sass({
                outputStyle: 'expanded',
                indentType: 'space',
                indentWidth: 4
            })).on('error', sass.logError)
            .pipe(autoprefixer({
                browsers: ['last 5 versions']
            }))
            .pipe(sourcemaps.write())
            .pipe(concat('style.css'))
			.pipe(minify())
            .pipe(gulp.dest(path.styles.output))
		done();
    });

// Spin up livereload server and listen for file changes
    gulp.task('listen', function (done) {

        gulp.watch(path.styles.input).on('change', gulp.series(['styles', 'refresh']));
        gulp.watch(path.scripts.input).on('change', gulp.series(['scripts', 'refresh']));
    });

// Run livereload after file change
    gulp.task('refresh', function () {
        return browserSync.reload();
    });
    return gulp.parallel(task);
	
}; //End function


//
var taskList = [];
// Add task from settings on/off
for (var key in settings.task){
    if(settings.task[key] === true || settings.task[key] === "true") taskList.push(key);
}

// Add task listen
taskList.push('listen');

// hard code to test each task
// var taskList = ['html'];

exports.runTask = compile(settings.paths, taskList);

gulp.task('default', compile(settings.paths, taskList));


// gulp.task('default', gulp.series(taskList), function () {
//
// });


// gulp.task('default', gulp.parallel(taskList), function () {
//
// });
